@@ -14,6 +14,8 @@
 #' Defaults to true
 #' @param OPC logical indicating whether or not to perform OPC calculation Defaults
 #' to false
+#' @param Slope logical indicating whether or not to perform Slope calculation, Defaults
+#' to true
 #' @param Details logical indicating whether or not to save the details of the RFI and
 #' OPCr calculations
 #' @param DNE_outliers the percentile at which outliers will be excluded is passed to
@@ -38,6 +40,8 @@
 #' counted in the OPC function. Defaults to 3.
 #' @param OPC_minimum_area minimum percentage of the surface area a patch must
 #' make up to be counted in the OPC function. Defaults to off
+#' @param Slope_Guess logical indicating whether or not to Guess as to the orientation
+#' of the surface during the Slope calculation (see Slope function for details)
 #' @param Parameters defaults to off. When engaged a list of all the parameters used
 #' during molaR analysis will be appended to the output file. 
 #'
@@ -54,15 +58,16 @@
 
 
 molaR_Batch <- function (pathname = getwd(), filename = "molaR_Batch.csv", DNE = TRUE, 
-          RFI = TRUE, OPCr = TRUE, OPC = FALSE, Details = FALSE, DNE_outliers = 0.1, 
+          RFI = TRUE, OPCr = TRUE, OPC = FALSE, Slope= TRUE, Details = FALSE, DNE_outliers = 0.1, 
           DNE_BoundaryDiscard = "Leg", RFI_alpha = 0.01, OPCr_steps = 8, 
           OPCr_stepSize = 5.626, OPCr_minimum_faces = 3, OPCr_minimum_area = 0, 
-          OPC_rotation = 0, OPC_minimum_faces = 3, OPC_minimum_area = 0, Parameters = FALSE) 
+          OPC_rotation = 0, OPC_minimum_faces = 3, OPC_minimum_area = 0, Slope_Guess = FALSE,
+          Parameters = FALSE) 
 {
   if((nchar(filename)-regexpr(".csv", filename, fixed=T)[[1]])!=3){
   	filename <- paste(sep="", filename, ".csv")
   }
-  if (DNE == FALSE && RFI == FALSE && OPCr == FALSE && OPC == FALSE) {
+  if (DNE == FALSE && RFI == FALSE && OPCr == FALSE && OPC == FALSE && Slope == FALSE) {
     stop("No metrics were selected to run")
   }
   fileNames <- dir(pathname, pattern = "*.ply")
@@ -74,6 +79,7 @@ molaR_Batch <- function (pathname = getwd(), filename = "molaR_Batch.csv", DNE =
   RFI_Output <- vector("numeric")
   OPCr_Output <- vector("numeric")
   OPC_Output <- vector("numeric")
+  Slope_Output <- vector("numeric")
   if (Details == TRUE) {
     ThreeD_Area <- vector("numeric")
     TwoD_Area <- vector("numeric")
@@ -82,7 +88,9 @@ molaR_Batch <- function (pathname = getwd(), filename = "molaR_Batch.csv", DNE =
     Rotations <- matrix(nrow = length(fileNames), ncol = length(RotDegrees))
     colnames(Rotations) <- paste(as.character(RotDegrees), 
                                  "deg.")
+    CorrectlyOriented <- vector("logical")
   }
+  cat("\nBeginning batch processing...")
   for (i in 1:fileNum) {
     invisible(capture.output(Specimen <- molaR_Clean(vcgPlyRead(file.path(pathname, 
                                                                           fileNames[i])))))
@@ -92,7 +100,7 @@ molaR_Batch <- function (pathname = getwd(), filename = "molaR_Batch.csv", DNE =
                                 BoundaryDiscard = DNE_BoundaryDiscard))
       }))
       if (is.character(DNE_Specimen)) {
-        DNE_Output = c(DNE_Output, DNE_Specimen)
+        DNE_Output <- c(DNE_Output, DNE_Specimen)
       }
       else {
         DNE_Result <- DNE_Specimen$Surface_DNE
@@ -133,7 +141,7 @@ molaR_Batch <- function (pathname = getwd(), filename = "molaR_Batch.csv", DNE =
                                   minimum_area = OPCr_minimum_area))
       }))
       if (is.character(OPCr_Specimen)) {
-        OPCr_Output = c(OPCr_Output, OPCr_Specimen)
+        OPCr_Output <- c(OPCr_Output, OPCr_Specimen)
         if (Details == TRUE) {
           for (j in 1:OPCr_steps) {
             Rotations[i, j] <- NA
@@ -153,11 +161,38 @@ molaR_Batch <- function (pathname = getwd(), filename = "molaR_Batch.csv", DNE =
     }
     if (OPC == TRUE) {
       invisible(capture.output({
-        OPC_Specimen <- OPC(Specimen, rotation = OPC_rotation, 
-                            minimum_faces = OPC_minimum_faces, minimum_area = OPC_minimum_area)
+        OPC_Specimen <- try(OPC(Specimen, rotation = OPC_rotation, 
+                            minimum_faces = OPC_minimum_faces, minimum_area = OPC_minimum_area))
       }))
-      OPC_Result <- OPC_Specimen$Patch_Count$`total patches`
-      OPC_Output <- c(OPC_Output, OPC_Result)
+      if (is.character(OPC_Specimen)) {
+        OPC_Output <- c(OPC_Output, OPC_Specimen)
+      }
+      else{
+        OPC_Result <- OPC_Specimen$Patch_Count$`total patches`
+        OPC_Output <- c(OPC_Output, OPC_Result)
+      }
+    }
+    if (Slope == TRUE) {
+      invisible(capture.output({
+        Slope_Specimen <- try(Slope(Specimen, Guess = Slope_Guess))
+      }))
+      if (is.character(Slope_Specimen)) {
+        Slope_Output <- c(Slope_Output, Slope_Specimen)
+        if (Details==TRUE) {
+          CorrectlyOriented <- c(CorrectlyOriented, NA)
+        }
+      }
+      else{
+        Slope_Result <- Slope_Specimen$Mean_Surface_Slope
+        Slope_Output <- c(Slope_Output, Slope_Result)
+        if (Details == TRUE) {
+          if (Slope_Specimen[2]=='Surface is likely Inverted'){
+            Oriented_Specimen <- FALSE
+          }
+          else{Oriented_Specimen <- TRUE}
+          CorrectlyOriented <- c(CorrectlyOriented, Oriented_Specimen)
+        }
+      }
     }
     cat("\nProcessed", i, "of", fileNum, "total PLY files in directory")
   }
@@ -181,6 +216,12 @@ molaR_Batch <- function (pathname = getwd(), filename = "molaR_Batch.csv", DNE =
   if (OPC == TRUE) {
     Output <- cbind(Output, OPC = OPC_Output)
   }
+  if (Slope == TRUE) {
+    Output <- cbind(Output, Slope = Slope_Output)
+    if (Details ==TRUE) {
+      Output <- cbind(Output, CorrectlyOriented)
+    }
+  }
   cat("\n")
   print(Output)
   if (Parameters == TRUE){
@@ -205,12 +246,16 @@ molaR_Batch <- function (pathname = getwd(), filename = "molaR_Batch.csv", DNE =
       newParam7 <- c("OPCr_minimum_area", OPCr_minimum_area, rep("", Blanks))
       paramList <- rbind(paramList, newParam4, newParam5, newParam6, newParam7)
     }
-    if (OPC ==TRUE) {
+    if (OPC == TRUE) {
       newParam8 <- c("OPC_rotation", OPC_rotation, rep("", Blanks))
       newParam9 <- c("OPC_minimum_faces", OPC_minimum_faces, rep("", Blanks))
       newParam10 <- c("OPC_minimum_area", OPC_minimum_area, rep("", Blanks))
       paramList <- rbind(paramList, newParam8, newParam9, newParam10)
     }
+    if (Slope == TRUE){
+      newParam11 <- c("Slope_Guess", Slope_Guess, rep("", Blanks))
+      paramList <- rbind(paramList, newParam11)
+    }
     Output <- rbind(Output, paramList)
   }
   write.csv(Output, file = file.path(pathname, filename), row.names = FALSE)
